//	TorusGamesMacOSView.h
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import <Cocoa/Cocoa.h>
#import "TorusGames-Common.h"
#import "TorusGamesMacOSCallbacks.h"


@interface TorusGamesMacOSView : NSOpenGLView
{
	IBOutlet NSButton		*itsResetButton,
							*itsChangeGameButton;

	IBOutlet NSWindow		*itsGameChoicePanel;

	IBOutlet NSDrawer		*itsCrosswordCluesDrawer;
	IBOutlet NSTextField	*itsCrosswordLabelAcross,
							*itsCrosswordLabelDown,
							*itsCrosswordClueAcross,
							*itsCrosswordClueDown;
	
	IBOutlet NSDrawer		*itsWordSearchListDrawer;
	IBOutlet NSTextView		*itsWordSearchList;
	
	IBOutlet NSDrawer		*itsPoolStatusDrawer;
	IBOutlet NSTextField	*itsPoolStatus;
	
	//	An NSTimer supports continuous redraw.
	NSTimer					*itsTimer;
	
	//	The Microseconds clock lets us keep the animation smooth
	//	regardless of the frame rate.
	long long				itsLastRenderTime;
	
	//	If we're displaying the frame rate in the title bar,
	//	we'll want to update it only about once per second.
	long long				itsLastFrameRateTime;
	
	//	Cocoa automatically remembers the "last directory" but really
	//	we need a separate "last directory" for each type of file,
	//	for example for the last TIFF image saved.
	NSMutableString			*itsLastImageDirectory;
	
	//	Does the cursor live on the torus or Klein bottle?
	bool					itsTorusCursorFlag;
	
	//	A Cocoa drawer realizes the abstract side window.
	SideWindow				itsMacOSSideWindow;

	//	Keep track of the Game menu's special menu item, if any.
	NSMenuItem				*itsMenuGameSpecial;

	//	The ModelData contains all the information about the space itself
	//	along with all platform-independent information about how
	//	it is to be displayed.
	ModelData				md;
}

+ (NSOpenGLPixelFormat*)pixelFormatSupportingMultisampling:(bool)aMultisampleFlag;
- (id)initWithFrame:(NSRect)frameRect;
- (void)dealloc;
- (void)awakeFromNib;
- (void)applicationDidFinishLaunching:(NSNotification *)aNotification;
- (IBAction)runGameChoicePanel:(id)sender;
- (IBAction)gameChoicePanelSelection:(id)sender;
- (void)localizeGameChoicePanel;
- (NSSize)windowWillResize:(NSWindow *)sender toSize:(NSSize)frameSize;
- (BOOL)acceptsFirstResponder;
- (void)setRedrawWithSync:(bool)aSyncFlag;
- (void)pleaseRedraw;
- (void)keyDown:(NSEvent *)anEvent;
- (void)insertText:(id)aString;
- (BOOL)performKeyEquivalent:(NSEvent *)anEvent;
- (void)mouseDown:(NSEvent *)anEvent;
- (void)mouseDown:(NSEvent *)anEvent withRightButton:(bool)aRightClickFlag;
- (void)mouseDragged:(NSEvent *)anEvent;
- (void)mouseMoved:(NSEvent *)anEvent;
- (void)mouseUp:(NSEvent *)anEvent;
- (void)rightMouseDown:(NSEvent *)anEvent;
- (void)rightMouseDragged:(NSEvent *)anEvent;
- (void)rightMouseUp:(NSEvent *)anEvent;
- (void)enterTorusCursorMode;
- (void)exitTorusCursorMode;
- (NSPoint)mouseLocation:(NSEvent *)anEvent;
- (void)drawRect:(NSRect)bounds;
- (BOOL)validateMenuItem:(NSMenuItem *)aMenuItem;

- (IBAction)commandGameReset:(id)sender;
- (IBAction)commandGameSpecial:(id)sender;
- (IBAction)commandGameTicTacToe:(id)sender;
- (IBAction)commandGameMaze:(id)sender;
- (IBAction)commandGameCrossword:(id)sender;
- (IBAction)commandGameWordSearch:(id)sender;
- (IBAction)commandGameJigsaw:(id)sender;
- (IBAction)commandGameChess:(id)sender;
- (IBAction)commandGamePool:(id)sender;
- (IBAction)commandGameApples:(id)sender;

- (IBAction)commandOptionsHumanVsHuman:(id)sender;
- (IBAction)commandOptionsHumanVsComputer:(id)sender;
- (IBAction)commandOptionsExtraEasy:(id)sender;
- (IBAction)commandOptionsEasy:(id)sender;
- (IBAction)commandOptionsMedium:(id)sender;
- (IBAction)commandOptionsHard:(id)sender;
- (IBAction)commandOptionsExtraHard:(id)sender;
- (IBAction)commandOptionsGlideReflections:(id)sender;
- (IBAction)commandOptionsSound:(id)sender;
- (IBAction)commandOptionsExportCopy:(id)sender;
- (IBAction)commandOptionsExportSave:(id)sender;

- (IBAction)commandTopologyTorus:(id)sender;
- (IBAction)commandTopologyKlein:(id)sender;

- (IBAction)commandViewDomainLarge:(id)sender;
- (IBAction)commandViewDomainSmall:(id)sender;
- (IBAction)commandViewTiling:(id)sender;

- (IBAction)commandLanguageDe:(id)sender;
- (IBAction)commandLanguageEn:(id)sender;
- (IBAction)commandLanguageEs:(id)sender;
- (IBAction)commandLanguageFr:(id)sender;
- (IBAction)commandLanguageHu:(id)sender;
- (IBAction)commandLanguageIt:(id)sender;
- (IBAction)commandLanguageJa:(id)sender;
- (IBAction)commandLanguageKo:(id)sender;
- (IBAction)commandLanguageNl:(id)sender;
- (IBAction)commandLanguagePt:(id)sender;
- (IBAction)commandLanguageRu:(id)sender;
- (IBAction)commandLanguageVi:(id)sender;

- (IBAction)commandHelpHowToPlay:(id)sender;
- (IBAction)commandHelpWraparoundUniverse:(id)sender;
- (IBAction)commandHelpPracticeBoard:(id)sender;
- (IBAction)commandHelpContact:(id)sender;

- (void)changeGameMacOS:(GameType)aNewGame;
- (void)prepareFonts;
- (void)prepareSideWindow;
- (void)prepareGameMenu;
- (void)changeLanguage:(NSString *)aLanguageCode;
- (NSMenu *)buildLocalizedMenuBar;
- (NSMenu *)addToMenu:(NSMenu *)aParentMenu submenuWithTitle:(char *)aSubmenuTitle;
- (NSString *)gameSpecificResetText;
- (void)copyImage;
- (void)saveImage;
- (NSImage *)contentsAsImage;
- (NSData *)contentsAsTIFF;
- (NSBitmapImageRep *)contentsAsBitmapImageRep;
- (void)invertRawImage:(unsigned int *)aPixelBuffer pixelsWide:(unsigned int)aWidth pixelsHigh:(unsigned int)aHeight;
- (void)reshape;
- (void)windowWillMiniaturize:(NSNotification *)aNotification;
- (BOOL)windowShouldClose:(id)sender;
- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)theApplication;
- (NSApplicationTerminateReply)applicationShouldTerminate:(NSApplication *)sender;
- (void)applicationWillTerminate:(NSNotification *)aNotification;
@end
