//	TorusGames-Win32.h
//
//	Definitions for Torus Games's Win32 user interface.
//	The user interface knows about the ModelData,
//	but doesn't know anything about OpenGL.
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#pragma once

//	Include platform-independent definitions (excluding OpenGL).
#include "TorusGames-Common.h"

//	Include the Win32 headers.
//	Request the WIN32_LEAN_AND_MEAN headers
//	using 16-bit UNICODE characters.
#define WIN32_LEAN_AND_MEAN
#define UNICODE
#include <windows.h>

//	Allow space for a toolbar.
#define TORUS_GAMES_WIN32_TOOLBAR_HEIGHT	32

//	The user never sees the window class names.
#define MAIN_WINDOW_CLASS_NAME		L"Torus Games Main Window Class"
#define DRAWING_WINDOW_CLASS_NAME	L"Torus Games Drawing Window Class"
#define SIDE_WINDOW_CLASS_NAME		L"Torus Games Side Window Class"

//	Realize the Font structure,
//	which the platform-independent code defined only as an opaque typedef.
struct Font
{
	HFONT	itsHFONT;
};

//	Realize the SideWindow structure,
//	which the platform-independent code defined only as an opaque typedef.
struct SideWindow
{
	HWND		itsHWND,
				itsTextField1,
				itsTextField2;
	COLORREF	itsTextColor1,
				itsTextColor2;
};


//	All the information needed to render a scene
//	lives in a single struct attached to the window.
typedef struct
{
	//	The main window
	HWND		itsWindow;
	
	//	The toolbar buttons
	HFONT		itsButtonFont;
	HWND		itsResetButton,
				itsChangeGameButton;
	HFONT		itsChangeGamePanelFont;

	//	Draw into a child window of the main window.
	HWND		itsDrawingPanel;

	//	Basic OpenGL rendering context.
	HDC			itsDeviceContext;
	HGLRC		itsRenderingContext;

	//	Keep track of the active tab in the preferences dialog, if any.
	HWND		itsPreferencesPane;
	
	//	Win32 fonts realize the abstract fonts.
	Font		itsWin32Fonts[NumberOfFonts];
	
	//	A Win32 window realizes the abstract side window.
	SideWindow	itsWin32SideWindow;

	//	Keep all platform-independent data in a ModelData struct
	//	(see TorusGames-Common.h for details).
	ModelData	md;

} WindowData;


//	Win32-specific global variables

//	An "atom" uniquely identifies the main window class.
extern ATOM			gMainWindowClass;

//	The user's preferred directory for saving images may differ
//	from his/her preferred directory for saving or opening other files.
extern WCHAR		gLastImageDirectory[MAX_PATH];


//	Win32-specific global functions

//	in TorusGames-Win32-WinMain.c
extern HWND				CreateTorusGamesWindow(void);
extern void				GetInitialWindowRect(DWORD aWindowStyles, RECT *aBestWindowRect);
extern BOOL CALLBACK	SetWindowTitle(HWND aWindow, LPARAM aTitle);

//	in TorusGames-Win32-WndProc.c
extern LRESULT CALLBACK	MainWndProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam);
extern void				ShowChangeGameDialog(WindowData *wd);
extern LRESULT CALLBACK	DrawingWndProc(HWND aDrawingWindow, UINT uMsg, WPARAM wParam, LPARAM lParam);
extern BOOL CALLBACK	RefreshLanguage(HWND aWindow, LPARAM anUnusedParameter);

//	in TorusGames-Win32-Utilities.c
extern WCHAR			*GetLocalizedTextAsWCHAR(const char *aKey, WCHAR *aValueBuffer, unsigned int aValueBufferLength);
extern bool				LanguageReadsRightToLeft(void);

//	in AVIMovie.c (optional)
extern ErrorText		MakeOpenGLMovie(WindowData *wd);
