// 	TorusGamesLanguageController.m
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import "TorusGamesLanguageController.h"
#import "TorusGames-Common.h"	//	for SAME_LANGUAGE_CODE
#import "TorusGamesPodOSUtilities.h"

struct
{
	char	itsTwoLetterCode[2];
	char	*itsName;
} gLanguageNames[] =
{
	{"de",	"Deutsch"	},
	{"en",	"English"	},
	{"es",	"Español"	},
	{"fr",	"Français"	},
	{"hu",	"Magyar"	},
	{"it",	"Italiano"	},
	{"ja",	"日本語"		},
	{"nl",	"Nederlands"},
	{"pt",	"Português"	},
	{"ru",	"Русский"	},
	{"vi",	"Tiếng Việt"}
};


@implementation TorusGamesLanguageController

- (id)initWithParent:(TorusGamesTabBarController *)aParent language:(char [3])aLanguageChoice
{
	if ((self = [super initWithTag:TabPageLanguage parent:aParent]) != nil)
	{
		itsLanguageChoice = aLanguageChoice;
	}
	return self;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)aTableView
{
	return 1;
}

- (NSString *)tableView:(UITableView *)aTableView titleForHeaderInSection:(NSInteger)aSection
{
	return GetLocalizedTextAsNSString("Language");
}

- (NSInteger)tableView:(UITableView *)aTableView numberOfRowsInSection:(NSInteger)aSection
{
	return BUFFER_LENGTH(gLanguageNames);
}

- (UITableViewCell *)tableView:(UITableView *)aTableView cellForRowAtIndexPath:(NSIndexPath *)anIndexPath
{
	UITableViewCell	*theCell;
	UILabel			*theLabel;
	unsigned int	theRow;
	NSString		*theTitle;
	bool			theCheckmark;

	theCell			= [[[UITableViewCell alloc] initWithFrame:CGRectZero reuseIdentifier:nil] autorelease];
	theLabel		= [theCell textLabel];
	theRow			= [anIndexPath row];
	theTitle		= [NSString stringWithUTF8String:gLanguageNames[theRow].itsName];
	theCheckmark	= SAME_LANGUAGE_CODE(gLanguageNames[theRow].itsTwoLetterCode, itsLanguageChoice);

	[theLabel setText:theTitle];
	[theCell setAccessoryType:(theCheckmark ? UITableViewCellAccessoryCheckmark : UITableViewCellAccessoryNone)];
	[[theCell imageView] setImage:[UIImage imageNamed:
		[NSString stringWithFormat:@"Table Images/Language-%c%c.png",
			gLanguageNames[theRow].itsTwoLetterCode[0],
			gLanguageNames[theRow].itsTwoLetterCode[1]]]];

	return theCell;
}

- (NSIndexPath *)tableView:(UITableView *)aTableView willSelectRowAtIndexPath:(NSIndexPath *)anIndexPath
{
	unsigned int	theRow;

	theRow	= [anIndexPath row];
	
	itsLanguageChoice[0] = gLanguageNames[theRow].itsTwoLetterCode[0];
	itsLanguageChoice[1] = gLanguageNames[theRow].itsTwoLetterCode[1];
	itsLanguageChoice[2] = 0;

	//	Record the new language code and initialize a dictionary
	//	immediately, so the TorusGamesTabBarController can update 
	//	all TorusGamesTabPageControllers in the new language.
	//	RefreshLocalization() will set gLanguageCode.
	RefreshLocalization(gLanguageNames[theRow].itsTwoLetterCode);

	[self buttonWasPressed];

	return nil;
}

@end
