// 	TorusGamesMainViewController.h
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import <UIKit/UIKit.h>
#import "TorusGamesTabBarController.h"

@class	TorusGamesModelData,
		TorusGamesEAGLView,
		CADisplayLink,
		TorusGamesKeyboardView;

@interface TorusGamesMainViewController : UIViewController
			<UIApplicationDelegate, TorusGamesTabBarControllerParent>
{
	IBOutlet TorusGamesModelData	*itsModelData;

	IBOutlet UIView					*itsEnclosingView;
	IBOutlet UILabel				*itsMessageField;
	IBOutlet UIView					*itsGLViewContainer;
	IBOutlet UIImageView			*itsBevel;
	IBOutlet TorusGamesEAGLView		*itsGLView;
	
	IBOutlet UIToolbar				*itsToolbar;
	IBOutlet UIBarButtonItem		*itsResetButton,
									*itsSettingsButton;

	//	A timer drives the animation.
	CADisplayLink			*itsAnimationTimer;
	
	//	The clock lets us keep the animation smooth regardless of the frame rate.
	double					itsLastRenderTime;	//	in seconds, with unknown precision or accuracy

	//	Interpret touch events.
	//	Initial touch events get withheld from the game
	//	until we determine whether a touch is a flick or not.
	bool					itsTouchIsResolved;
	CGPoint					itsUnresolvedTouchPoint,
							itsUnresolvedTouchMotion;
	double					itsUnresolvedTouchDuration;
	NSTimer					*itsUnresolvedTouchTimer;

	//	The Crossword will need a keyboard.
	//	When any other game is active, this pointer should be nil.
	TorusGamesKeyboardView	*itsKeyboard;

	//	When the user changes the options, 
	//	compare the new values to the old to decide what to refresh.
	TorusGamesSettings		itsPreviousSettings;
	
	//	When the user re-opens the TorusGamesTabBarController,
	//	let it begin with the same tab the user viewed the previous time.
	TabPageTag				itsDefaultTab;
}

- (id)initWithCoder:(NSCoder *)decoder;
- (void)awakeFromNib;
- (void)applicationDidFinishLaunching:(UIApplication *)application;
- (void)applicationDidReceiveMemoryWarning:(UIApplication *)application;
- (void)applicationWillTerminate:(UIApplication *)application;
- (void)dealloc;

- (void)makeBevel;

- (void)startAnimation;
- (void)stopAnimation;
- (void)pleaseRedraw:(CADisplayLink *)aDisplayLink;

- (void)touchBeganAt:(CGPoint)aPoint;
- (void)touchMovedAcross:(CGPoint)aMotion during:(double)aDuration;
- (void)touchEnded;
- (void)touchCancelled;
#ifdef INTERPRET_FLICKS
- (void)touchResolvedByTimeout:(NSTimer *)theTimer;
- (void)touchResolvesToFlick:(bool)aFlickFlag;
#endif

- (void)setMessageText:(NSString *)aMessage;
- (void)setMessageFontSizeForMessage:(NSString *)aMessage;

- (IBAction)resetGameWithAnimation;
- (void)resetGame;
- (void)halfwayPoint;

- (void)changeGamePodOS:(GameType)aNewGame;
- (void)refreshGameLanguageWithReset:(bool)aResetFlag;
- (void)refreshToolbar;

- (void)refreshCrosswordTextEntry;
- (IBAction)showToolbarBriefly:(id)sender;
- (void)showToolbarWithAnimation;
- (void)hideToolbarWithAnimation;

- (IBAction)showTabBarController;
- (void)tabBarControllerDidFinishWithSettings:(TorusGamesSettings)someNewSettings tab:(TabPageTag)aLastTab;

@end
