// 	TorusGamesModelData.m
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import "TorusGamesModelData.h"
#import "TorusGamesMainViewController.h"
#import "EAGL.h"


@implementation TorusGamesModelData

- (id)init
{
	if ((self = [super init]) != nil)
	{
		//	Set harmless defaults for the ModelData,
		//	without assuming the presence of OpenGL or anything else.
		//	In particular, set all pointers to NULL so that
		//	dealloc() can call ShutDownModelData() safely.
		SetUpModelData(&itsModelData);
	}

	return self;
}

- (void)dealloc
{
	//	This method never gets called.
	//	See comments in TorusGamesMainViewController's dealloc method.
	[super dealloc];
}

- (void)clearModelDataWithContext:(EAGLContext *)aContext
{
	//	Free memory and generally clean up as best we can.
	//	In other words, do the stuff that we'd do in dealloc
	//	if dealloc were getting called.

	//	Switch to the null game.
	[self changeGame:GameNone context:aContext];

	//	Free the ModelData.
	ShutDownModelData(&itsModelData);
}

- (ModelData *)modelData
{
	return &itsModelData;
}


- (void)changeGame:(GameType)aNewGame context:(EAGLContext *)aContext
{
	//	Shut down the old game.
	//	Make sure the OpenGL ES context is current
	//	so the old game can release its shaders, textures,
	//	whose OpenGL "names" only it knows.
	[EAGLContext setCurrentContext:aContext];
	ShutDownGame(&itsModelData);
	[EAGLContext setCurrentContext:nil];

	//	Switch to the new game.
	itsModelData.itsGame = aNewGame;

	//	Set up the new game.
	SetUpGame(&itsModelData);

	//	Ask the idle-time routine to redraw the scene.
	itsModelData.itsRedrawRequestFlag = true;
}


@end
