// 	TorusGamesOptionsController.m
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import "TorusGamesOptionsController.h"
#import "TorusGamesPodOSUtilities.h"

struct
{
	bool		itsHumanVsComputer;
	char		*itsName;
	NSString	*itsImageName;
} gPlayModeNames[] =
{
	{false,	"Human vs. Human",		@"Table Images/Players-HumanVsHuman.png"	},
	{true,	"Human vs. Computer",	@"Table Images/Players-HumanVsComputer.png"	}
};

struct
{
	TopologyType	itsTopology;
	char			*itsName;
	NSString		*itsImageName;
} gTopologyNames[] =
{
	{TopologyTorus,	"Torus",		@"Table Images/Topology-Torus.png"	},
	{TopologyKlein,	"Klein Bottle",	@"Table Images/Topology-Klein.png"	}
};


@implementation TorusGamesOptionsController

- (id)initWithParent:(TorusGamesTabBarController *)aParent game:(GameType)aGame topologyChoice:(TopologyType *)aTopologyChoice humanVsComputerChoice:(bool *)aHumanVsComputerChoice
{
	if ((self = [super initWithTag:TabPageOptions parent:aParent]) != nil)
	{
		itsGame						= aGame;
		itsTopologyChoice			= aTopologyChoice;
		itsHumanVsComputerChoice	= aHumanVsComputerChoice;
	}
	return self;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)aTableView
{
	return 2;
}

- (NSString *)tableView:(UITableView *)aTableView titleForHeaderInSection:(NSInteger)aSection
{
	switch (aSection)
	{
		case 0:		return GetLocalizedTextAsNSString("Players" );
		case 1:		return GetLocalizedTextAsNSString("Topology");
		default:	return @"?";
	}
}

- (NSInteger)tableView:(UITableView *)aTableView numberOfRowsInSection:(NSInteger)aSection
{
	switch (aSection)
	{
		case 0:		return BUFFER_LENGTH(gPlayModeNames);
		case 1:		return BUFFER_LENGTH(gTopologyNames);
		default:	return 0;
	}
}

- (UITableViewCell *)tableView:(UITableView *)aTableView cellForRowAtIndexPath:(NSIndexPath *)anIndexPath
{
	UITableViewCell	*theCell;
	UILabel			*theLabel;
	unsigned int	theSection,
					theRow;
	NSString		*theTitle;
	bool			theCheckmark;
	NSString		*theImageName;

	theCell			= [[[UITableViewCell alloc] initWithFrame:CGRectZero reuseIdentifier:nil] autorelease];
	theLabel		= [theCell textLabel];
	theSection		= [anIndexPath section];
	theRow			= [anIndexPath row];

	switch (theSection)
	{
		case 0:
			theTitle = GetLocalizedTextAsNSString(gPlayModeNames[theRow].itsName);
			if (itsGame == GameNone
			 || itsGame == GameTicTacToe
			 || itsGame == GameChess
			 || itsGame == GamePool)
			{
				theCheckmark = (gPlayModeNames[theRow].itsHumanVsComputer == *itsHumanVsComputerChoice);
			}
			else
			{
				[theLabel setTextColor:[UIColor grayColor]];
				theCheckmark = false;
			}
			theImageName = gPlayModeNames[theRow].itsImageName;
			break;

		case 1:
			theTitle		= GetLocalizedTextAsNSString(gTopologyNames[theRow].itsName);
			theCheckmark	= (gTopologyNames[theRow].itsTopology == *itsTopologyChoice);
			theImageName	= gTopologyNames[theRow].itsImageName;
			break;

		default:
			theTitle		= @"?";
			theCheckmark	= false;
			theImageName	= @"?";
			break;
	}

	[theLabel setText:theTitle];
	[theCell setAccessoryType:(theCheckmark ? UITableViewCellAccessoryCheckmark : UITableViewCellAccessoryNone)];
	[[theCell imageView] setImage:[UIImage imageNamed:theImageName]];

	return theCell;
}

- (NSIndexPath *)tableView:(UITableView *)aTableView willSelectRowAtIndexPath:(NSIndexPath *)anIndexPath
{
	unsigned int	theSection,
					theRow;

	theSection	= [anIndexPath section];
	theRow		= [anIndexPath row];

	switch (theSection)
	{
		case 0:
			if (itsGame == GameNone
			 || itsGame == GameTicTacToe
			 || itsGame == GameChess
			 || itsGame == GamePool)
			{
				*itsHumanVsComputerChoice = gPlayModeNames[theRow].itsHumanVsComputer;
			}
			break;

		case 1:
			*itsTopologyChoice = gTopologyNames[theRow].itsTopology;
			break;

		default:
			break;
	}

	[self buttonWasPressed];

	return nil;
}

@end
