// 	TorusGamesTabBarController.m
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import "TorusGamesTabBarController.h"
#import "TorusGamesGameChoiceController.h"
#import "TorusGamesOptionsController.h"
#import "TorusGamesLanguageController.h"
#import "TorusGamesHelpController.h"


@implementation TorusGamesTabBarController


- (id)initWithParent:(id <TorusGamesTabBarControllerParent>)aParent
		settings:(TorusGamesSettings)someInitialSettings
		tab:(TabPageTag)anInitialTab
{
	NSMutableArray	*theControllers;

	if ((self = [super initWithNibName:nil bundle:nil]) != nil)
	{
		//	Set itsParent.
		itsParent = aParent;
		
		//	Copy someInitialSettings.
		//	The Game Choice, Options and Language controllers
		//	we all get pointers to this same shared copy of the settings.
		itsSettings = someInitialSettings;
		
		//	Initialize an empty array.
		theControllers = [NSMutableArray arrayWithCapacity:5];
		
		//	Load a TorusGamesGamesChoiceController into the first tab.
		[theControllers addObject:[[[TorusGamesGameChoiceController alloc]
				initWithParent:			self
				gameChoice:				&itsSettings.itsGame
			] autorelease]];
		
		//	Load a TorusGamesOptionsController into the second tab.
		[theControllers addObject:[[[TorusGamesOptionsController alloc]
				initWithParent:			self
				game:					itsSettings.itsGame
				topologyChoice:			&itsSettings.itsTopology
				humanVsComputerChoice:	&itsSettings.itsHumanVsComputer
			] autorelease]];
		
		//	Load a TorusGamesLanguageController into the third tab.
		[theControllers addObject:[[[TorusGamesLanguageController alloc]
				initWithParent:			self
				language:				itsSettings.itsLanguageCode
			] autorelease]];
		
		//	Load a TorusGamesHelpController into the fourth tab.
		[theControllers addObject:[[[TorusGamesHelpController alloc]
				initWithParent:			self
				gameChoice:				&itsSettings.itsGame
				filler:					0
			] autorelease]];
		
		//	Install all the tab controllers.
		[self setViewControllers:theControllers];
		
		//	Select the requested tab.
		[self setSelectedIndex:anInitialTab];
	}
	return self;
}


- (void)buttonWasPressedInPage:(TabPageTag)aTabPageTag
{
	switch (aTabPageTag)
	{
		case TabPageGameChoice:
				break;

		case TabPageOptions:
			break;

		case TabPageLanguage:
			[[self viewControllers] makeObjectsPerformSelector:@selector(refreshLanguage)];
			break;

		case TabPageHelp:
			break;

		default:
			//	Should never occur.
			break;
	}

	//	If at any time since launch a game has been selected...
	if (itsSettings.itsGame != GameNone)
	{
		//	...then dismiss the TorusGamesTabBarController
		//	and return to (or switch to) the selected game.
		[itsParent tabBarControllerDidFinishWithSettings:itsSettings tab:aTabPageTag];
	}
	else	//	Otherwise...
	{
		//	...switch to the Game panel to encourage the user to choose one.
		[self setSelectedIndex:TabPageGameChoice];
	}
}


@end
