// 	TorusGamesWebViewController.m
//
//	© 2010 by Jeff Weeks
//	See TermsOfUse.txt

#import "TorusGamesWebViewController.h"
#import "TorusGamesPodOSUtilities.h"


#define NAVBARHEIGHT	44.0	//	pixels


@implementation TorusGamesWebViewController

- (id)initWithDirectory:(NSString *)aDirectoryName page:(NSString *)aFileName
{
	if ((self = [super initWithNibName:nil bundle:nil]) != nil)
	{
		itsDirectoryName		= [aDirectoryName copy];
		itsFileName				= [aFileName copy];
		itsActivityIndicator	= nil;
		itsWebView				= nil;
	}
	return self;
}

- (void)dealloc
{
	[itsDirectoryName release];
	[itsFileName      release];

	//	The superclass UIViewController may or may not
	//	call viewDidUnload, so let's call it now to be safe.
	[self viewDidUnload];

	[super dealloc];
}

- (void)loadView
{
	UIView				*theContainerView;
	UINavigationBar		*theNavigationBar;
	UINavigationItem	*theTitle;
	UIBarButtonItem		*theDoneButton;
	
	theContainerView = [[UIView alloc] initWithFrame:(CGRect){{0.0, 0.0}, {320.0, 480.0}}];

		theNavigationBar = [[UINavigationBar alloc] initWithFrame:(CGRect){{0.0, 0.0}, {320.0, NAVBARHEIGHT}}];

			theTitle = [[UINavigationItem alloc] initWithTitle:@""];

				theDoneButton = [[UIBarButtonItem alloc]
					initWithTitle:	GetLocalizedTextAsNSString("Close")
					style:			UIBarButtonItemStyleDone
					target:			self
					action:			@selector(dismiss)];
				[theTitle setRightBarButtonItem:theDoneButton];
				[theDoneButton release];

			[theNavigationBar pushNavigationItem:theTitle animated:NO];
			[theTitle release];
			
			itsActivityIndicator = [[UIActivityIndicatorView alloc]
				initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhite];

				[itsActivityIndicator setCenter:(CGPoint){NAVBARHEIGHT/2, NAVBARHEIGHT/2}];

			[theNavigationBar addSubview:itsActivityIndicator];
		//	[itsActivityIndicator release];		A weak reference would probably be good enough,
		//										but let's retain itsActivityIndicator just to be safe.

		[theContainerView addSubview:theNavigationBar];
		[theNavigationBar release];
		
		itsWebView = [[UIWebView alloc] initWithFrame:(CGRect){{0.0, NAVBARHEIGHT}, {320.0, 480.0 - NAVBARHEIGHT}}];

			[itsWebView setDelegate:self];
			[itsWebView
				loadData:			[NSData dataWithContentsOfFile:[[NSBundle mainBundle]
										pathForResource:itsFileName ofType:nil inDirectory:itsDirectoryName]]
				MIMEType:			@"text/html"
				textEncodingName:	@"utf-8"
				baseURL:			[NSURL	fileURLWithPath:	[[[NSBundle mainBundle] resourcePath]
																	stringByAppendingPathComponent:itsDirectoryName]
											isDirectory:		YES]
			];

		[theContainerView addSubview:itsWebView];
	//	[theWebView release];  Normally we'd release the UIWebView,
	//	leaving only theContainerView holding a reference to it.
	//	But -- see comments in viewDidUnload -- it seems we need
	//	to retain a private reference to the UIWebView, so we
	//	do NOT release it here.

	[self setView:theContainerView];
	[theContainerView release];
}

- (void)viewDidUnload
{
	//	dealloc will definitely call viewDidUnload,
	//	perhaps redundantly but usually of necessity.
	//	So make sure nothing bad will happen
	//	if viewDidUnload gets called twice in succession.
	//	Fortunately it's explicitly OK to send messages
	//	to a nil object, for example [nil release] 
	//	is both legal and harmless.

	//	Release itsActivityIndicator.
	[itsActivityIndicator release];
	itsActivityIndicator = nil;
	
	//	The UIWebViewDelegate documentation says
	//
	//		Important: Before releasing an instance of UIWebView 
	//		for which you have set a delegate, you must first set 
	//		the UIWebView delegate property to nil before disposing
	//		of the UIWebView instance.  This can be done, for example,
	//		in the dealloc method where you dispose of the UIWebView.
	//
	//	To comply with this bizarre request, we've kept our own
	//	private reference to the UIWebView, which we release now.
	[itsWebView setDelegate:nil];
	[itsWebView release];
	itsWebView = nil;
}

- (void)dismiss
{
	[[self parentViewController] dismissModalViewControllerAnimated:YES];
}


- (BOOL)webView:(UIWebView *)webView shouldStartLoadWithRequest:(NSURLRequest *)request navigationType:(UIWebViewNavigationType)navigationType
{
	return YES;
}

- (void)webViewDidStartLoad:(UIWebView *)webView
{
	[itsActivityIndicator startAnimating];
}

- (void)webViewDidFinishLoad:(UIWebView *)webView
{
	[itsActivityIndicator stopAnimating];
}

- (void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error
{
	UIAlertView	*theErrorAlert;

	[itsActivityIndicator stopAnimating];
	
	if (error != nil)
	{
		theErrorAlert = [[UIAlertView alloc]
			initWithTitle:		[error localizedDescription]
			message:			[error localizedFailureReason]
			delegate:			nil
			cancelButtonTitle:	@"OK"
			otherButtonTitles:	nil];
		[theErrorAlert show];
		[theErrorAlert release];
	}
}


@end
